@@ -6,6 +6,7 @@ from airflow.utils.dates import days_ago
 from airflow.utils.helpers import chain
 from dagster.core.snap import PipelineSnapshot
 from dagster.serdes import serialize_pp
+from dagster_airflow.dagster_job_factory import make_dagster_job_from_airflow_dag
 from dagster_airflow.dagster_pipeline_factory import make_dagster_pipeline_from_airflow_dag
 
 default_args = {
@@ -438,3 +439,25 @@ def test_complex_dag(snapshot):
             ).dep_structure_snapshot
         )
     )
+
+
+def test_one_task_dag_to_job():
+    dag = DAG(
+        dag_id="dag-with.dot-dash",
+        default_args=default_args,
+        schedule_interval=None,
+    )
+    dummy_operator = DummyOperator(
+        task_id="dummy_operator",
+        dag=dag,
+    )
+    job_def = make_dagster_job_from_airflow_dag(dag=dag)
+
+    assert job_def.name == "airflow_dag_with_dot_dash"
+    assert len([job_def.solids]) == 1
+    result = job_def.execute_in_process()
+
+    assert result.success
+    step_success_events = [evt for evt in result.all_node_events if evt.is_step_success]
+    assert len(step_success_events) == 1
+    assert step_success_events[0].step_key == "airflow_dummy_operator"
